@@ -28,6 +28,8 @@ import os
 
 import numpy
 from PIL import Image
+from tifffile import TiffFile
+
 import pyworkflow.utils as pwutils
 import pwem.objects as emobj
 import pwem.constants as emcts
@@ -256,6 +258,12 @@ class ImageHandler(object):
                     'eman2.convert', 'getImageDimensions',
                     doRaise=True)
                 return getImageDimensions(fn)  # we are ignoring index here
+            elif ext == '.eer':
+                tif = TiffFile(fn)
+                frames = len(tif.pages)  # number of pages in the file
+                page = tif.pages[0]  # get shape and dtype of the image in the first page
+                x, y = page.shape
+                return x, y, frames, 1
             else:
                 self._img.read(location, lib.HEADER)
                 return self._img.getDimensions()
@@ -424,7 +432,11 @@ class ImageHandler(object):
         """ Check if imgFn has an image extension. The function
         is implemented in the Xmipp binding.
         """
-        return lib.FileName(imgFn).isImage()
+        # Local import to avoid import loop between ImageHandler and Ccp4Header.
+        from pwem.convert import headers
+
+        return (lib.FileName(imgFn).isImage() or
+                headers.getFileFormat(imgFn) == headers.MRC)
 
     def computeThumbnail(self, inputFn, outputFn, scaleFactor=6, flipOnY=False,
                          flipOnX=False):
