@@ -162,7 +162,7 @@ class ProtImportImages(ProtImportFiles):
                     self._addImageToSet(img, imgSet)
             else:
                 img.setObjId(fileId)
-                img.setFileName(dst)
+                img.setLocation(dst)
                 # Fill the micName if img is either Micrograph or Movie
                 uniqueFn = uniqueFn.replace(' ', '')
                 self._fillMicName(img, uniqueFn)
@@ -350,6 +350,7 @@ class ProtImportImages(ProtImportFiles):
                 if (not self.dataStreaming and
                     not (imgFn.endswith('bz2') or
                          imgFn.endswith('tbz') or
+                         imgFn.endswith('eer') or
                          ih.isImageFile(imgFn))):
                     if not errors:  # if empty add the first line
                         errors.append("Error reading the following images:")
